@@ -44,7 +44,7 @@ class SpectacleConfig : public QObject
 
     private:
 
-    explicit SpectacleConfig(QObject *parent = 0);
+    explicit SpectacleConfig(QObject *parent = nullptr);
     virtual ~SpectacleConfig();
 
     SpectacleConfig(SpectacleConfig const&) = delete;
@@ -75,6 +75,9 @@ class SpectacleConfig : public QObject
     bool quitAfterSaveOrCopyChecked() const;
     void setQuitAfterSaveOrCopyChecked(bool enabled);
 
+    bool showMagnifierChecked() const;
+    void setShowMagnifierChecked(bool enabled);
+
     qreal captureDelay() const;
     void setCaptureDelay(qreal delay);
 
